@@ -164,7 +164,7 @@ def del_assignments(sender, **kwargs):
     objs.delete()
 
 
-class PTUser(NetBoxModel):
+class PTUsers(NetBoxModel):
     name = models.CharField(
         max_length=250,
         unique=False
@@ -246,7 +246,7 @@ class PTUser(NetBoxModel):
         return reverse('plugins:ptuevents:ptusers', args=[self.pk])
 
 
-class PTWorkstation(NetBoxModel):
+class PTWorkstations(NetBoxModel):
 
     name = models.CharField(
         max_length=100,
